# Summary

- Subject ID: 10
- Structural images: 1 T1-weighted
- Functional series: 1

- Task: mixedgamblestask (1 run)

- Standard output spaces: MNI152NLin2009cAsym
- Non-standard output spaces:
- FreeSurfer reconstruction: Run by fMRIPrep

# Anatomical

### Anatomical Conformation

- Input T1w images: 1
- Output orientation: RAS
- Output dimensions: 160x192x192
- Output voxel size: 1mm x 1.3mm x 1.3mm
- Discarded images: 0

### Brain mask and brain tissue segmentation of the T1w

This panel shows the template T1-weighted image (if several T1w images were found), with contours delineating the detected brain mask and brain tissue segmentations.

Get figure file: figures/sub-10_dseg.svg

### Spatial normalization of the anatomical T1w reference

Results of nonlinear alignment of the T1w reference one or more template space(s). Hover on the panels with the mouse pointer to transition between both spaces.

Spatial normalization of the T1w image to the `MNI152NLin2009cAsym` template.

Get figure file: figures/sub-10_space-MNI152NLin2009cAsym_T1w.svg

### Surface reconstruction

Surfaces (white and pial) reconstructed with FreeSurfer (`recon-all`) overlaid on the participant's T1w template.

Get figure file: figures/sub-10_desc-reconall_T1w.svg

# Functional

## Reports for: task mixedgamblestask, run 1.

Summary

- Repetition time (TR): 2s
- Phase-encoding (PE) direction: MISSING - Assuming Anterior-Posterior
- Single-echo EPI sequence.
- Slice timing correction: Not applied
- Susceptibility distortion correction: None
- Registration: FreeSurfer `bbregister` (boundary-based registration, BBR) - 6 dof
- Non-steady-state volumes: 1

Confounds collected

global_signal, global_signal_derivative1, global_signal_power2, global_signal_derivative1_power2, csf, csf_derivative1, csf_derivative1_power2, csf_power2, white_matter, white_matter_derivative1, white_matter_power2, white_matter_derivative1_power2, csf_wm, tcompcor, std_dvars, dvars, framewise_displacement, rmsd, t_comp_cor_00, t_comp_cor_01, t_comp_cor_02, t_comp_cor_03, t_comp_cor_04, t_comp_cor_05, a_comp_cor_00, a_comp_cor_01, a_comp_cor_02, a_comp_cor_03, a_comp_cor_04, a_comp_cor_05, a_comp_cor_06, a_comp_cor_07, a_comp_cor_08, a_comp_cor_09, a_comp_cor_10, a_comp_cor_11, a_comp_cor_12, a_comp_cor_13, a_comp_cor_14, a_comp_cor_15, a_comp_cor_16, a_comp_cor_17, a_comp_cor_18, a_comp_cor_19, a_comp_cor_20, a_comp_cor_21, a_comp_cor_22, a_comp_cor_23, a_comp_cor_24, a_comp_cor_25, a_comp_cor_26, a_comp_cor_27, a_comp_cor_28, a_comp_cor_29, a_comp_cor_30, a_comp_cor_31, a_comp_cor_32, a_comp_cor_33, a_comp_cor_34, a_comp_cor_35, a_comp_cor_36, a_comp_cor_37, a_comp_cor_38, a_comp_cor_39, a_comp_cor_40, a_comp_cor_41, a_comp_cor_42, a_comp_cor_43, a_comp_cor_44, a_comp_cor_45, a_comp_cor_46, a_comp_cor_47, a_comp_cor_48, a_comp_cor_49, a_comp_cor_50, a_comp_cor_51, a_comp_cor_52, a_comp_cor_53, a_comp_cor_54, a_comp_cor_55, a_comp_cor_56, a_comp_cor_57, a_comp_cor_58, a_comp_cor_59, a_comp_cor_60, a_comp_cor_61, a_comp_cor_62, a_comp_cor_63, a_comp_cor_64, a_comp_cor_65, a_comp_cor_66, a_comp_cor_67, a_comp_cor_68, a_comp_cor_69, a_comp_cor_70, a_comp_cor_71, a_comp_cor_72, a_comp_cor_73, a_comp_cor_74, a_comp_cor_75, a_comp_cor_76, a_comp_cor_77, a_comp_cor_78, a_comp_cor_79, a_comp_cor_80, a_comp_cor_81, a_comp_cor_82, a_comp_cor_83, a_comp_cor_84, a_comp_cor_85, a_comp_cor_86, a_comp_cor_87, a_comp_cor_88, a_comp_cor_89, a_comp_cor_90, a_comp_cor_91, a_comp_cor_92, a_comp_cor_93, a_comp_cor_94, a_comp_cor_95, a_comp_cor_96, a_comp_cor_97, a_comp_cor_98, a_comp_cor_99, a_comp_cor_100, a_comp_cor_101, a_comp_cor_102, a_comp_cor_103, a_comp_cor_104, a_comp_cor_105, a_comp_cor_106, a_comp_cor_107, a_comp_cor_108, a_comp_cor_109, a_comp_cor_110, a_comp_cor_111, a_comp_cor_112, a_comp_cor_113, a_comp_cor_114, a_comp_cor_115, a_comp_cor_116, a_comp_cor_117, a_comp_cor_118, a_comp_cor_119, a_comp_cor_120, a_comp_cor_121, a_comp_cor_122, a_comp_cor_123, a_comp_cor_124, a_comp_cor_125, a_comp_cor_126, a_comp_cor_127, a_comp_cor_128, a_comp_cor_129, a_comp_cor_130, a_comp_cor_131, a_comp_cor_132, a_comp_cor_133, a_comp_cor_134, a_comp_cor_135, a_comp_cor_136, a_comp_cor_137, a_comp_cor_138, a_comp_cor_139, a_comp_cor_140, a_comp_cor_141, a_comp_cor_142, a_comp_cor_143, a_comp_cor_144, a_comp_cor_145, a_comp_cor_146, a_comp_cor_147, a_comp_cor_148, a_comp_cor_149, a_comp_cor_150, a_comp_cor_151, a_comp_cor_152, cosine00, cosine01, cosine02, cosine03, cosine04, cosine05, non_steady_state_outlier00, trans_x, trans_x_derivative1, trans_x_power2, trans_x_derivative1_power2, trans_y, trans_y_derivative1, trans_y_derivative1_power2, trans_y_power2, trans_z, trans_z_derivative1, trans_z_power2, trans_z_derivative1_power2, rot_x, rot_x_derivative1, rot_x_power2, rot_x_derivative1_power2, rot_y, rot_y_derivative1, rot_y_power2, rot_y_derivative1_power2, rot_z, rot_z_derivative1, rot_z_power2, rot_z_derivative1_power2, motion_outlier00, motion_outlier01, motion_outlier02, motion_outlier03, motion_outlier04, motion_outlier05.

### Alignment of functional and anatomical MRI data (surface driven)

`bbregister` was used to generate transformations from EPI-space to T1w-space. Note that Nearest Neighbor interpolation is used in the reportlets in order to highlight potential spin-history and other artifacts, whereas final images are resampled using Lanczos interpolation.

Get figure file: figures/sub-10_task-mixedgamblestask_run-1_desc-bbregister_bold.svg

### Brain mask and (anatomical/crown/temporal) CompCor ROIs

Brain mask calculated on the BOLD signal (red contour), along with the regions of interest (ROIs) used in a/crown/tCompCor for extracting physiological and movement confounding components.
The anatomical CompCor ROI (magenta contour) is a mask combining CSF and WM (white-matter), where voxels containing a minimal partial volume of GM have been removed.
The crown CompCor ROI (coral contour) corresponds to the crown mask, that is voxels in a closed band around the brain.
The temporal CompCor ROI (blue contour) contains the top 2% most variable voxels within the brain mask.

Get figure file: figures/sub-10_task-mixedgamblestask_run-1_desc-rois_bold.svg

### Variance explained by a/crown/tCompCor components

The cumulative variance explained by the first k components of the a/crown/tCompCor decomposition, plotted for all values of k. The number of components that must be included in the model in order to explain some fraction of variance in the decomposition mask can be used as a feature selection criterion for confound regression.

Get figure file: figures/sub-10_task-mixedgamblestask_run-1_desc-compcorvar_bold.svg

### BOLD Summary

Summary statistics are plotted, which may reveal trends or artifacts in the BOLD data. Global signals calculated within the whole-brain (GS), within the white-matter (WM) and within cerebro-spinal fluid (CSF) show the mean BOLD signal in their corresponding masks. DVARS and FD show the standardized DVARS and framewise-displacement measures for each time point.
A carpet plot shows the time series for all voxels within the brain mask, or if `--cifti-output` was enabled, all grayordinates. Voxels are grouped into cortical (Ctx GM), subcortical/deep (dGM) gray matter, deep white matter and CSF (dWM+dCSF), shallow white matter and CSF (sWM+sCSF), cerebellum (Cb) and the edge that corresponds to the voxels located on a closed band around the brain .

Get figure file: figures/sub-10_task-mixedgamblestask_run-1_desc-carpetplot_bold.svg

### Correlations among nuisance regressors

Left: Heatmap summarizing the correlation structure among confound variables. (Cosine bases and PCA-derived CompCor components are inherently orthogonal.) Right: magnitude of the correlation between each confound time series and the mean global signal. Strong correlations might be indicative of partial volume effects and can inform decisions about feature orthogonalization prior to confound regression.

Get figure file: figures/sub-10_task-mixedgamblestask_run-1_desc-confoundcorr_bold.svg

# About

- fMRIPrep version: 20.2.3
- fMRIPrep command: `/usr/local/miniconda/bin/fmriprep /data /out participant --participant-label 10 -w /work --nprocs 20 --omp-nthreads 16 -vv`
- Date preprocessed: 2021-08-20 07:56:04 +0000

# Methods

We kindly ask to report results preprocessed with this tool using the following boilerplate.

Results included in this manuscript come from preprocessing performed using fMRIPrep 20.2.3 (Esteban, Markiewicz, et al. (2018); Esteban, Blair, et al. (2018); RRID:SCR_016216), which is based on Nipype 1.6.1 (Gorgolewski et al. (2011); Gorgolewski et al. (2018); RRID:SCR_002502).

Anatomical data preprocessing

  A total of 1 T1-weighted (T1w) images were found within the input BIDS dataset.The T1-weighted (T1w) image was corrected for intensity non-uniformity (INU) with `N4BiasFieldCorrection` (Tustison et al. 2010), distributed with ANTs 2.3.3 (Avants et al. 2008, RRID:SCR_004757), and used as T1w-reference throughout the workflow. The T1w-reference was then skull-stripped with a Nipype implementation of the `antsBrainExtraction.sh` workflow (from ANTs), using OASIS30ANTs as target template. Brain tissue segmentation of cerebrospinal fluid (CSF), white-matter (WM) and gray-matter (GM) was performed on the brain-extracted T1w using `fast` (FSL 5.0.9, RRID:SCR_002823, Zhang, Brady, and Smith 2001). Brain surfaces were reconstructed using `recon-all` (FreeSurfer 6.0.1, RRID:SCR_001847, Dale, Fischl, and Sereno 1999), and the brain mask estimated previously was refined with a custom variation of the method to reconcile ANTs-derived and FreeSurfer-derived segmentations of the cortical gray-matter of Mindboggle (RRID:SCR_002438, Klein et al. 2017). Volume-based spatial normalization to one standard space (MNI152NLin2009cAsym) was performed through nonlinear registration with `antsRegistration` (ANTs 2.3.3), using brain-extracted versions of both T1w reference and the T1w template. The following template was selected for spatial normalization: ICBM 152 Nonlinear Asymmetrical template version 2009c [Fonov et al. (2009), RRID:SCR_008796; TemplateFlow ID: MNI152NLin2009cAsym],

Functional data preprocessing

  For each of the 3 BOLD runs found per subject (across all tasks and sessions), the following preprocessing was performed. First, a reference volume and its skull-stripped version were generated using a custom methodology of fMRIPrep. Susceptibility distortion correction (SDC) was omitted. The BOLD reference was then co-registered to the T1w reference using `bbregister` (FreeSurfer) which implements boundary-based registration (Greve and Fischl 2009). Co-registration was configured with six degrees of freedom. Head-motion parameters with respect to the BOLD reference (transformation matrices, and six corresponding rotation and translation parameters) are estimated before any spatiotemporal filtering using `mcflirt` (FSL 5.0.9, Jenkinson et al. 2002). The BOLD time-series (including slice-timing correction when applied) were resampled onto their original, native space by applying the transforms to correct for head-motion. These resampled BOLD time-series will be referred to as preprocessed BOLD in original space, or just preprocessed BOLD. The BOLD time-series were resampled into standard space, generating a preprocessed BOLD run in MNI152NLin2009cAsym space. First, a reference volume and its skull-stripped version were generated using a custom methodology of fMRIPrep. Several confounding time-series were calculated based on the preprocessed BOLD: framewise displacement (FD), DVARS and three region-wise global signals. FD was computed using two formulations following Power (absolute sum of relative motions, Power et al. (2014)) and Jenkinson (relative root mean square displacement between affines, Jenkinson et al. (2002)). FD and DVARS are calculated for each functional run, both using their implementations in Nipype (following the definitions by Power et al. 2014). The three global signals are extracted within the CSF, the WM, and the whole-brain masks. Additionally, a set of physiological regressors were extracted to allow for component-based noise correction (CompCor, Behzadi et al. 2007). Principal components are estimated after high-pass filtering the preprocessed BOLD time-series (using a discrete cosine filter with 128s cut-off) for the two CompCor variants: temporal (tCompCor) and anatomical (aCompCor). tCompCor components are then calculated from the top 2% variable voxels within the brain mask. For aCompCor, three probabilistic masks (CSF, WM and combined CSF+WM) are generated in anatomical space. The implementation differs from that of Behzadi et al. in that instead of eroding the masks by 2 pixels on BOLD space, the aCompCor masks are subtracted a mask of pixels that likely contain a volume fraction of GM. This mask is obtained by dilating a GM mask extracted from the FreeSurfer’s aseg segmentation, and it ensures components are not extracted from voxels containing a minimal fraction of GM. Finally, these masks are resampled into BOLD space and binarized by thresholding at 0.99 (as in the original implementation). Components are also calculated separately within the WM and CSF masks. For each CompCor decomposition, the k components with the largest singular values are retained, such that the retained components’ time series are sufficient to explain 50 percent of variance across the nuisance mask (CSF, WM, combined, or temporal). The remaining components are dropped from consideration. The head-motion estimates calculated in the correction step were also placed within the corresponding confounds file. The confound time series derived from head motion estimates and global signals were expanded with the inclusion of temporal derivatives and quadratic terms for each (Satterthwaite et al. 2013). Frames that exceeded a threshold of 0.5 mm FD or 1.5 standardised DVARS were annotated as motion outliers. All resamplings can be performed with a single interpolation step by composing all the pertinent transformations (i.e. head-motion transform matrices, susceptibility distortion correction when available, and co-registrations to anatomical and output spaces). Gridded (volumetric) resamplings were performed using `antsApplyTransforms` (ANTs), configured with Lanczos interpolation to minimize the smoothing effects of other kernels (Lanczos 1964). Non-gridded (surface) resamplings were performed using `mri_vol2surf` (FreeSurfer).

Many internal operations of fMRIPrep use Nilearn 0.6.2 (Abraham et al. 2014, RRID:SCR_001362), mostly within the functional processing workflow. For more details of the pipeline, see the section corresponding to workflows in fMRIPrep’s documentation.

### Copyright Waiver

The above boilerplate text was automatically generated by fMRIPrep with the express intention that users should copy and paste this text into their manuscripts unchanged. It is released under the CC0 license.

### References

Abraham, Alexandre, Fabian Pedregosa, Michael Eickenberg, Philippe Gervais, Andreas Mueller, Jean Kossaifi, Alexandre Gramfort, Bertrand Thirion, and Gael Varoquaux. 2014. “Machine Learning for Neuroimaging with Scikit-Learn.” Frontiers in Neuroinformatics 8. https://doi.org/10.3389/fninf.2014.00014.

Avants, B.B., C.L. Epstein, M. Grossman, and J.C. Gee. 2008. “Symmetric Diffeomorphic Image Registration with Cross-Correlation: Evaluating Automated Labeling of Elderly and Neurodegenerative Brain.” Medical Image Analysis 12 (1): 26–41. https://doi.org/10.1016/j.media.2007.06.004.

Behzadi, Yashar, Khaled Restom, Joy Liau, and Thomas T. Liu. 2007. “A Component Based Noise Correction Method (CompCor) for BOLD and Perfusion Based fMRI.” NeuroImage 37 (1): 90–101. https://doi.org/10.1016/j.neuroimage.2007.04.042.

Dale, Anders M., Bruce Fischl, and Martin I. Sereno. 1999. “Cortical Surface-Based Analysis: I. Segmentation and Surface Reconstruction.” NeuroImage 9 (2): 179–94. https://doi.org/10.1006/nimg.1998.0395.

Esteban, Oscar, Ross Blair, Christopher J. Markiewicz, Shoshana L. Berleant, Craig Moodie, Feilong Ma, Ayse Ilkay Isik, et al. 2018. “FMRIPrep.” Software. Zenodo. https://doi.org/10.5281/zenodo.852659.

Esteban, Oscar, Christopher Markiewicz, Ross W Blair, Craig Moodie, Ayse Ilkay Isik, Asier Erramuzpe Aliaga, James Kent, et al. 2018. “fMRIPrep: A Robust Preprocessing Pipeline for Functional MRI.” Nature Methods. https://doi.org/10.1038/s41592-018-0235-4.

Fonov, VS, AC Evans, RC McKinstry, CR Almli, and DL Collins. 2009. “Unbiased Nonlinear Average Age-Appropriate Brain Templates from Birth to Adulthood.” NeuroImage 47, Supplement 1: S102. https://doi.org/10.1016/S1053-8119(09)70884-5.

Gorgolewski, K., C. D. Burns, C. Madison, D. Clark, Y. O. Halchenko, M. L. Waskom, and S. Ghosh. 2011. “Nipype: A Flexible, Lightweight and Extensible Neuroimaging Data Processing Framework in Python.” Frontiers in Neuroinformatics 5: 13. https://doi.org/10.3389/fninf.2011.00013.

Gorgolewski, Krzysztof J., Oscar Esteban, Christopher J. Markiewicz, Erik Ziegler, David Gage Ellis, Michael Philipp Notter, Dorota Jarecka, et al. 2018. “Nipype.” Software. Zenodo. https://doi.org/10.5281/zenodo.596855.

Greve, Douglas N, and Bruce Fischl. 2009. “Accurate and Robust Brain Image Alignment Using Boundary-Based Registration.” NeuroImage 48 (1): 63–72. https://doi.org/10.1016/j.neuroimage.2009.06.060.

Jenkinson, Mark, Peter Bannister, Michael Brady, and Stephen Smith. 2002. “Improved Optimization for the Robust and Accurate Linear Registration and Motion Correction of Brain Images.” NeuroImage 17 (2): 825–41. https://doi.org/10.1006/nimg.2002.1132.

Klein, Arno, Satrajit S. Ghosh, Forrest S. Bao, Joachim Giard, Yrjö Häme, Eliezer Stavsky, Noah Lee, et al. 2017. “Mindboggling Morphometry of Human Brains.” PLOS Computational Biology 13 (2): e1005350. https://doi.org/10.1371/journal.pcbi.1005350.

Lanczos, C. 1964. “Evaluation of Noisy Data.” Journal of the Society for Industrial and Applied Mathematics Series B Numerical Analysis 1 (1): 76–85. https://doi.org/10.1137/0701007.

Power, Jonathan D., Anish Mitra, Timothy O. Laumann, Abraham Z. Snyder, Bradley L. Schlaggar, and Steven E. Petersen. 2014. “Methods to Detect, Characterize, and Remove Motion Artifact in Resting State fMRI.” NeuroImage 84 (Supplement C): 320–41. https://doi.org/10.1016/j.neuroimage.2013.08.048.

Satterthwaite, Theodore D., Mark A. Elliott, Raphael T. Gerraty, Kosha Ruparel, James Loughead, Monica E. Calkins, Simon B. Eickhoff, et al. 2013. “An improved framework for confound regression and filtering for control of motion artifact in the preprocessing of resting-state functional connectivity data.” NeuroImage 64 (1): 240–56. https://doi.org/10.1016/j.neuroimage.2012.08.052.

Tustison, N. J., B. B. Avants, P. A. Cook, Y. Zheng, A. Egan, P. A. Yushkevich, and J. C. Gee. 2010. “N4ITK: Improved N3 Bias Correction.” IEEE Transactions on Medical Imaging 29 (6): 1310–20. https://doi.org/10.1109/TMI.2010.2046908.

Zhang, Y., M. Brady, and S. Smith. 2001. “Segmentation of Brain MR Images Through a Hidden Markov Random Field Model and the Expectation-Maximization Algorithm.” IEEE Transactions on Medical Imaging 20 (1): 45–57. https://doi.org/10.1109/42.906424.

    Results included in this manuscript come from preprocessing
    performed using *fMRIPrep* 20.2.3
    (@fmriprep1; @fmriprep2; RRID:SCR_016216),
    which is based on *Nipype* 1.6.1
    (@nipype1; @nipype2; RRID:SCR_002502).

    Anatomical data preprocessing

    : A total of 1 T1-weighted (T1w) images were found within the input
    BIDS dataset.The T1-weighted (T1w) image was corrected for intensity non-uniformity (INU)
    with `N4BiasFieldCorrection` [@n4], distributed with ANTs 2.3.3 [@ants, RRID:SCR_004757], and used as T1w-reference throughout the workflow.
    The T1w-reference was then skull-stripped with a *Nipype* implementation of
    the `antsBrainExtraction.sh` workflow (from ANTs), using OASIS30ANTs
    as target template.
    Brain tissue segmentation of cerebrospinal fluid (CSF),
    white-matter (WM) and gray-matter (GM) was performed on
    the brain-extracted T1w using `fast` [FSL 5.0.9, RRID:SCR_002823,
    @fsl_fast].
    Brain surfaces were reconstructed using `recon-all` [FreeSurfer 6.0.1,
    RRID:SCR_001847, @fs_reconall], and the brain mask estimated
    previously was refined with a custom variation of the method to reconcile
    ANTs-derived and FreeSurfer-derived segmentations of the cortical
    gray-matter of Mindboggle [RRID:SCR_002438, @mindboggle].
    Volume-based spatial normalization to one standard space (MNI152NLin2009cAsym) was performed through
    nonlinear registration with `antsRegistration` (ANTs 2.3.3),
    using brain-extracted versions of both T1w reference and the T1w template.
    The following template was selected for spatial normalization:
    *ICBM 152 Nonlinear Asymmetrical template version 2009c* [@mni152nlin2009casym, RRID:SCR_008796; TemplateFlow ID: MNI152NLin2009cAsym],

    Functional data preprocessing

    : For each of the 1 BOLD run found per subject (across all
    tasks and sessions), the following preprocessing was performed.
    First, a reference volume and its skull-stripped version were generated
     using a custom
    methodology of *fMRIPrep*.
    Susceptibility distortion correction (SDC) was omitted.
    The BOLD reference was then co-registered to the T1w reference using
    `bbregister` (FreeSurfer) which implements boundary-based registration [@bbr].
    Co-registration was configured with six degrees of freedom.
    Head-motion parameters with respect to the BOLD reference
    (transformation matrices, and six corresponding rotation and translation
    parameters) are estimated before any spatiotemporal filtering using
    `mcflirt` [FSL 5.0.9, @mcflirt].
    The BOLD time-series (including slice-timing correction when applied)
    were resampled onto their original, native space by applying
    the transforms to correct for head-motion.
    These resampled BOLD time-series will be referred to as *preprocessed
    BOLD in original space*, or just *preprocessed BOLD*.
    The BOLD time-series were resampled into standard space,
    generating a *preprocessed BOLD run in MNI152NLin2009cAsym space*.
    First, a reference volume and its skull-stripped version were generated
     using a custom
    methodology of *fMRIPrep*.
    Several confounding time-series were calculated based on the
    *preprocessed BOLD*: framewise displacement (FD), DVARS and
    three region-wise global signals.
    FD was computed using two formulations following Power (absolute sum of
    relative motions, @power_fd_dvars) and Jenkinson (relative root mean square
    displacement between affines, @mcflirt).
    FD and DVARS are calculated for each functional run, both using their
    implementations in *Nipype* [following the definitions by @power_fd_dvars].
    The three global signals are extracted within the CSF, the WM, and
    the whole-brain masks.
    Additionally, a set of physiological regressors were extracted to
    allow for component-based noise correction [*CompCor*, @compcor].
    Principal components are estimated after high-pass filtering the
    *preprocessed BOLD* time-series (using a discrete cosine filter with
    128s cut-off) for the two *CompCor* variants: temporal (tCompCor)
    and anatomical (aCompCor).
    tCompCor components are then calculated from the top 2% variable
    voxels within the brain mask.
    For aCompCor, three probabilistic masks (CSF, WM and combined CSF+WM)
    are generated in anatomical space.
    The implementation differs from that of Behzadi et al. in that instead
    of eroding the masks by 2 pixels on BOLD space, the aCompCor masks are
    subtracted a mask of pixels that likely contain a volume fraction of GM.
    This mask is obtained by dilating a GM mask extracted from the FreeSurfer's *aseg* segmentation, and it ensures components are not extracted
    from voxels containing a minimal fraction of GM.
    Finally, these masks are resampled into BOLD space and binarized by
    thresholding at 0.99 (as in the original implementation).
    Components are also calculated separately within the WM and CSF masks.
    For each CompCor decomposition, the *k* components with the largest singular
    values are retained, such that the retained components' time series are
    sufficient to explain 50 percent of variance across the nuisance mask (CSF,
    WM, combined, or temporal). The remaining components are dropped from
    consideration.
    The head-motion estimates calculated in the correction step were also
    placed within the corresponding confounds file.
    The confound time series derived from head motion estimates and global
    signals were expanded with the inclusion of temporal derivatives and
    quadratic terms for each [@confounds_satterthwaite_2013].
    Frames that exceeded a threshold of 0.5 mm FD or
    1.5 standardised DVARS were annotated as motion outliers.
    All resamplings can be performed with *a single interpolation
    step* by composing all the pertinent transformations (i.e. head-motion
    transform matrices, susceptibility distortion correction when available,
    and co-registrations to anatomical and output spaces).
    Gridded (volumetric) resamplings were performed using `antsApplyTransforms` (ANTs),
    configured with Lanczos interpolation to minimize the smoothing
    effects of other kernels [@lanczos].
    Non-gridded (surface) resamplings were performed using `mri_vol2surf`
    (FreeSurfer).

    Many internal operations of *fMRIPrep* use
    *Nilearn* 0.6.2 [@nilearn, RRID:SCR_001362],
    mostly within the functional processing workflow.
    For more details of the pipeline, see [the section corresponding
    to workflows in *fMRIPrep*'s documentation](https://fmriprep.readthedocs.io/en/latest/workflows.html "FMRIPrep's documentation").

    ### Copyright Waiver

    The above boilerplate text was automatically generated by fMRIPrep
    with the express intention that users should copy and paste this
    text into their manuscripts *unchanged*.
    It is released under the [CC0](https://creativecommons.org/publicdomain/zero/1.0/) license.

    ### References

    Results included in this manuscript come from preprocessing performed
    using \emph{fMRIPrep} 20.2.3 (\citet{fmriprep1}; \citet{fmriprep2};
    RRID:SCR\_016216), which is based on \emph{Nipype} 1.6.1
    (\citet{nipype1}; \citet{nipype2}; RRID:SCR\_002502).

    \begin{description}
    \item[Anatomical data preprocessing]
    A total of 1 T1-weighted (T1w) images were found within the input BIDS
    dataset.The T1-weighted (T1w) image was corrected for intensity
    non-uniformity (INU) with \texttt{N4BiasFieldCorrection} \citep{n4},
    distributed with ANTs 2.3.3 \citep[RRID:SCR\_004757]{ants}, and used as
    T1w-reference throughout the workflow. The T1w-reference was then
    skull-stripped with a \emph{Nipype} implementation of the
    \texttt{antsBrainExtraction.sh} workflow (from ANTs), using OASIS30ANTs
    as target template. Brain tissue segmentation of cerebrospinal fluid
    (CSF), white-matter (WM) and gray-matter (GM) was performed on the
    brain-extracted T1w using \texttt{fast} \citep[FSL 5.0.9,
    RRID:SCR\_002823,][]{fsl_fast}. Brain surfaces were reconstructed using
    \texttt{recon-all} \citep[FreeSurfer 6.0.1,
    RRID:SCR\_001847,][]{fs_reconall}, and the brain mask estimated
    previously was refined with a custom variation of the method to
    reconcile ANTs-derived and FreeSurfer-derived segmentations of the
    cortical gray-matter of Mindboggle
    \citep[RRID:SCR\_002438,][]{mindboggle}. Volume-based spatial
    normalization to one standard space (MNI152NLin2009cAsym) was performed
    through nonlinear registration with \texttt{antsRegistration} (ANTs
    2.3.3), using brain-extracted versions of both T1w reference and the T1w
    template. The following template was selected for spatial normalization:
    \emph{ICBM 152 Nonlinear Asymmetrical template version 2009c}
    {[}\citet{mni152nlin2009casym}, RRID:SCR\_008796; TemplateFlow ID:
    MNI152NLin2009cAsym{]},
    \item[Functional data preprocessing]
    For each of the 1 BOLD run found per subject (across all tasks and
    sessions), the following preprocessing was performed. First, a reference
    volume and its skull-stripped version were generated using a custom
    methodology of \emph{fMRIPrep}. Susceptibility distortion correction
    (SDC) was omitted. The BOLD reference was then co-registered to the T1w
    reference using \texttt{bbregister} (FreeSurfer) which implements
    boundary-based registration \citep{bbr}. Co-registration was configured
    with six degrees of freedom. Head-motion parameters with respect to the
    BOLD reference (transformation matrices, and six corresponding rotation
    and translation parameters) are estimated before any spatiotemporal
    filtering using \texttt{mcflirt} \citep[FSL 5.0.9,][]{mcflirt}. The BOLD
    time-series (including slice-timing correction when applied) were
    resampled onto their original, native space by applying the transforms
    to correct for head-motion. These resampled BOLD time-series will be
    referred to as \emph{preprocessed BOLD in original space}, or just
    \emph{preprocessed BOLD}. The BOLD time-series were resampled into
    standard space, generating a \emph{preprocessed BOLD run in
    MNI152NLin2009cAsym space}. First, a reference volume and its
    skull-stripped version were generated using a custom methodology of
    \emph{fMRIPrep}. Several confounding time-series were calculated based
    on the \emph{preprocessed BOLD}: framewise displacement (FD), DVARS and
    three region-wise global signals. FD was computed using two formulations
    following Power (absolute sum of relative motions,
    \citet{power_fd_dvars}) and Jenkinson (relative root mean square
    displacement between affines, \citet{mcflirt}). FD and DVARS are
    calculated for each functional run, both using their implementations in
    \emph{Nipype} \citep[following the definitions by][]{power_fd_dvars}.
    The three global signals are extracted within the CSF, the WM, and the
    whole-brain masks. Additionally, a set of physiological regressors were
    extracted to allow for component-based noise correction
    \citep[\emph{CompCor},][]{compcor}. Principal components are estimated
    after high-pass filtering the \emph{preprocessed BOLD} time-series
    (using a discrete cosine filter with 128s cut-off) for the two
    \emph{CompCor} variants: temporal (tCompCor) and anatomical (aCompCor).
    tCompCor components are then calculated from the top 2\% variable voxels
    within the brain mask. For aCompCor, three probabilistic masks (CSF, WM
    and combined CSF+WM) are generated in anatomical space. The
    implementation differs from that of Behzadi et al.~in that instead of
    eroding the masks by 2 pixels on BOLD space, the aCompCor masks are
    subtracted a mask of pixels that likely contain a volume fraction of GM.
    This mask is obtained by dilating a GM mask extracted from the
    FreeSurfer's \emph{aseg} segmentation, and it ensures components are not
    extracted from voxels containing a minimal fraction of GM. Finally,
    these masks are resampled into BOLD space and binarized by thresholding
    at 0.99 (as in the original implementation). Components are also
    calculated separately within the WM and CSF masks. For each CompCor
    decomposition, the \emph{k} components with the largest singular values
    are retained, such that the retained components' time series are
    sufficient to explain 50 percent of variance across the nuisance mask
    (CSF, WM, combined, or temporal). The remaining components are dropped
    from consideration. The head-motion estimates calculated in the
    correction step were also placed within the corresponding confounds
    file. The confound time series derived from head motion estimates and
    global signals were expanded with the inclusion of temporal derivatives
    and quadratic terms for each \citep{confounds_satterthwaite_2013}.
    Frames that exceeded a threshold of 0.5 mm FD or 1.5 standardised DVARS
    were annotated as motion outliers. All resamplings can be performed with
    \emph{a single interpolation step} by composing all the pertinent
    transformations (i.e.~head-motion transform matrices, susceptibility
    distortion correction when available, and co-registrations to anatomical
    and output spaces). Gridded (volumetric) resamplings were performed
    using \texttt{antsApplyTransforms} (ANTs), configured with Lanczos
    interpolation to minimize the smoothing effects of other kernels
    \citep{lanczos}. Non-gridded (surface) resamplings were performed using
    \texttt{mri\_vol2surf} (FreeSurfer).
    \end{description}

    Many internal operations of \emph{fMRIPrep} use \emph{Nilearn} 0.6.2
    \citep[RRID:SCR\_001362]{nilearn}, mostly within the functional
    processing workflow. For more details of the pipeline, see
    \href{https://fmriprep.readthedocs.io/en/latest/workflows.html}{the
    section corresponding to workflows in \emph{fMRIPrep}'s documentation}.

    \hypertarget{copyright-waiver}{%
    \subsubsection{Copyright Waiver}\label{copyright-waiver}}

    The above boilerplate text was automatically generated by fMRIPrep with
    the express intention that users should copy and paste this text into
    their manuscripts \emph{unchanged}. It is released under the
    \href{https://creativecommons.org/publicdomain/zero/1.0/}{CC0} license.

    \hypertarget{references}{%
    \subsubsection{References}\label{references}}

    \bibliography{/usr/local/miniconda/lib/python3.7/site-packages/fmriprep/data/boilerplate.bib}

### Bibliography

    @article{fmriprep1,
        author = {Esteban, Oscar and Markiewicz, Christopher and Blair, Ross W and Moodie, Craig and Isik, Ayse Ilkay and Erramuzpe Aliaga, Asier and Kent, James and Goncalves, Mathias and DuPre, Elizabeth and Snyder, Madeleine and Oya, Hiroyuki and Ghosh, Satrajit and Wright, Jessey and Durnez, Joke and Poldrack, Russell and Gorgolewski, Krzysztof Jacek},
        title = {{fMRIPrep}: a robust preprocessing pipeline for functional {MRI}},
        year = {2018},
        doi = {10.1038/s41592-018-0235-4},
        journal = {Nature Methods}
    }

    @article{fmriprep2,
        author = {Esteban, Oscar and Blair, Ross and Markiewicz, Christopher J. and Berleant, Shoshana L. and Moodie, Craig and Ma, Feilong and Isik, Ayse Ilkay and Erramuzpe, Asier and Kent, James D. andGoncalves, Mathias and DuPre, Elizabeth and Sitek, Kevin R. and Gomez, Daniel E. P. and Lurie, Daniel J. and Ye, Zhifang and Poldrack, Russell A. and Gorgolewski, Krzysztof J.},
        title = {fMRIPrep},
        year = 2018,
        doi = {10.5281/zenodo.852659},
        publisher = {Zenodo},
        journal = {Software}
    }

    @article{nipype1,
        author = {Gorgolewski, K. and Burns, C. D. and Madison, C. and Clark, D. and Halchenko, Y. O. and Waskom, M. L. and Ghosh, S.},
        doi = {10.3389/fninf.2011.00013},
        journal = {Frontiers in Neuroinformatics},
        pages = 13,
        shorttitle = {Nipype},
        title = {Nipype: a flexible, lightweight and extensible neuroimaging data processing framework in Python},
        volume = 5,
        year = 2011
    }

    @article{nipype2,
        author = {Gorgolewski, Krzysztof J. and Esteban, Oscar and Markiewicz, Christopher J. and Ziegler, Erik and Ellis, David Gage and Notter, Michael Philipp and Jarecka, Dorota and Johnson, Hans and Burns, Christopher and Manhães-Savio, Alexandre and Hamalainen, Carlo and Yvernault, Benjamin and Salo, Taylor and Jordan, Kesshi and Goncalves, Mathias and Waskom, Michael and Clark, Daniel and Wong, Jason and Loney, Fred and Modat, Marc and Dewey, Blake E and Madison, Cindee and Visconti di Oleggio Castello, Matteo and Clark, Michael G. and Dayan, Michael and Clark, Dav and Keshavan, Anisha and Pinsard, Basile and Gramfort, Alexandre and Berleant, Shoshana and Nielson, Dylan M. and Bougacha, Salma and Varoquaux, Gael and Cipollini, Ben and Markello, Ross and Rokem, Ariel and Moloney, Brendan and Halchenko, Yaroslav O. and Wassermann , Demian and Hanke, Michael and Horea, Christian and Kaczmarzyk, Jakub and Gilles de Hollander and DuPre, Elizabeth and Gillman, Ashley and Mordom, David and Buchanan, Colin and Tungaraza, Rosalia and Pauli, Wolfgang M. and Iqbal, Shariq and Sikka, Sharad and Mancini, Matteo and Schwartz, Yannick and Malone, Ian B. and Dubois, Mathieu and Frohlich, Caroline and Welch, David and Forbes, Jessica and Kent, James and Watanabe, Aimi and Cumba, Chad and Huntenburg, Julia M. and Kastman, Erik and Nichols, B. Nolan and Eshaghi, Arman and Ginsburg, Daniel and Schaefer, Alexander and Acland, Benjamin and Giavasis, Steven and Kleesiek, Jens and Erickson, Drew and Küttner, René and Haselgrove, Christian and Correa, Carlos and Ghayoor, Ali and Liem, Franz and Millman, Jarrod and Haehn, Daniel and Lai, Jeff and Zhou, Dale and Blair, Ross and Glatard, Tristan and Renfro, Mandy and Liu, Siqi and Kahn, Ari E. and Pérez-García, Fernando and Triplett, William and Lampe, Leonie and Stadler, Jörg and Kong, Xiang-Zhen and Hallquist, Michael and Chetverikov, Andrey and Salvatore, John and Park, Anne and Poldrack, Russell and Craddock, R. Cameron and Inati, Souheil and Hinds, Oliver and Cooper, Gavin and Perkins, L. Nathan and Marina, Ana and Mattfeld, Aaron and Noel, Maxime and Lukas Snoek and Matsubara, K and Cheung, Brian and Rothmei, Simon and Urchs, Sebastian and Durnez, Joke and Mertz, Fred and Geisler, Daniel and Floren, Andrew and Gerhard, Stephan and Sharp, Paul and Molina-Romero, Miguel and Weinstein, Alejandro and Broderick, William and Saase, Victor and Andberg, Sami Kristian and Harms, Robbert and Schlamp, Kai and Arias, Jaime and Papadopoulos Orfanos, Dimitri and Tarbert, Claire and Tambini, Arielle and De La Vega, Alejandro and Nickson, Thomas and Brett, Matthew and Falkiewicz, Marcel and Podranski, Kornelius and Linkersdörfer, Janosch and Flandin, Guillaume and Ort, Eduard and Shachnev, Dmitry and McNamee, Daniel and Davison, Andrew and Varada, Jan and Schwabacher, Isaac and Pellman, John and Perez-Guevara, Martin and Khanuja, Ranjeet and Pannetier, Nicolas and McDermottroe, Conor and Ghosh, Satrajit},
        title = {Nipype},
        year = 2018,
        doi = {10.5281/zenodo.596855},
        publisher = {Zenodo},
        journal = {Software}
    }

    @article{n4,
        author = {Tustison, N. J. and Avants, B. B. and Cook, P. A. and Zheng, Y. and Egan, A. and Yushkevich, P. A. and Gee, J. C.},
        doi = {10.1109/TMI.2010.2046908},
        issn = {0278-0062},
        journal = {IEEE Transactions on Medical Imaging},
        number = 6,
        pages = {1310-1320},
        shorttitle = {N4ITK},
        title = {N4ITK: Improved N3 Bias Correction},
        volume = 29,
        year = 2010
    }

    @article{fs_reconall,
        author = {Dale, Anders M. and Fischl, Bruce and Sereno, Martin I.},
        doi = {10.1006/nimg.1998.0395},
        issn = {1053-8119},
        journal = {NeuroImage},
        number = 2,
        pages = {179-194},
        shorttitle = {Cortical Surface-Based Analysis},
        title = {Cortical Surface-Based Analysis: I. Segmentation and Surface Reconstruction},
        url = {http://www.sciencedirect.com/science/article/pii/S1053811998903950},
        volume = 9,
        year = 1999
    }

    @article{mindboggle,
        author = {Klein, Arno and Ghosh, Satrajit S. and Bao, Forrest S. and Giard, Joachim and Häme, Yrjö and Stavsky, Eliezer and Lee, Noah and Rossa, Brian and Reuter, Martin and Neto, Elias Chaibub and Keshavan, Anisha},
        doi = {10.1371/journal.pcbi.1005350},
        issn = {1553-7358},
        journal = {PLOS Computational Biology},
        number = 2,
        pages = {e1005350},
        title = {Mindboggling morphometry of human brains},
        url = {http://journals.plos.org/ploscompbiol/article?id=10.1371/journal.pcbi.1005350},
        volume = 13,
        year = 2017
    }

    @article{mni152lin,
        title = {A {Probabilistic} {Atlas} of the {Human} {Brain}: {Theory} and {Rationale} for {Its} {Development}: {The} {International} {Consortium} for {Brain} {Mapping} ({ICBM})},
        author = {Mazziotta, John C. and Toga, Arthur W. and Evans, Alan and Fox, Peter and Lancaster, Jack},
        volume = {2},
        issn = {1053-8119},
        shorttitle = {A {Probabilistic} {Atlas} of the {Human} {Brain}},
        doi = {10.1006/nimg.1995.1012},
        number = {2, Part A},
        journal = {NeuroImage},
        year = {1995},
        pages = {89--101}
    }

    @article{mni152nlin2009casym,
        title = {Unbiased nonlinear average age-appropriate brain templates from birth to adulthood},
        author = {Fonov, VS and Evans, AC and McKinstry, RC and Almli, CR and Collins, DL},
        doi = {10.1016/S1053-8119(09)70884-5},
        journal = {NeuroImage},
        pages = {S102},
        volume = {47, Supplement 1},
        year = 2009
    }

    @article{mni152nlin6asym,
        author = {Evans, AC and Janke, AL and Collins, DL and Baillet, S},
        title = {Brain templates and atlases},
        doi = {10.1016/j.neuroimage.2012.01.024},
        journal = {NeuroImage},
        volume = {62},
        number = {2},
        pages = {911--922},
        year = 2012
    }

    @article{ants,
        author = {Avants, B.B. and Epstein, C.L. and Grossman, M. and Gee, J.C.},
        doi = {10.1016/j.media.2007.06.004},
        issn = {1361-8415},
        journal = {Medical Image Analysis},
        number = 1,
        pages = {26-41},
        shorttitle = {Symmetric diffeomorphic image registration with cross-correlation},
        title = {Symmetric diffeomorphic image registration with cross-correlation: Evaluating automated labeling of elderly and neurodegenerative brain},
        url = {http://www.sciencedirect.com/science/article/pii/S1361841507000606},
        volume = 12,
        year = 2008
    }

    @article{fsl_fast,
        author = {Zhang, Y. and Brady, M. and Smith, S.},
        doi = {10.1109/42.906424},
        issn = {0278-0062},
        journal = {IEEE Transactions on Medical Imaging},
        number = 1,
        pages = {45-57},
        title = {Segmentation of brain {MR} images through a hidden Markov random field model and the expectation-maximization algorithm},
        volume = 20,
        year = 2001
    }

    @article{fieldmapless1,
        author = {Wang, Sijia and Peterson, Daniel J. and Gatenby, J. C. and Li, Wenbin and Grabowski, Thomas J. and Madhyastha, Tara M.},
        doi = {10.3389/fninf.2017.00017},
        issn = {1662-5196},
        journal = {Frontiers in Neuroinformatics},
        language = {English},
        title = {Evaluation of Field Map and Nonlinear Registration Methods for Correction of Susceptibility Artifacts in Diffusion {MRI}},
        url = {http://journal.frontiersin.org/article/10.3389/fninf.2017.00017/full},
        volume = 11,
        year = 2017
    }

    @phdthesis{fieldmapless2,
        address = {Berlin},
        author = {Huntenburg, Julia M.},
        language = {eng},
        school = {Freie Universität},
        title = {Evaluating nonlinear coregistration of {BOLD} {EPI} and T1w images},
        type = {Master's Thesis},
        url = {http://hdl.handle.net/11858/00-001M-0000-002B-1CB5-A},
        year = 2014
    }

    @article{fieldmapless3,
        author = {Treiber, Jeffrey Mark and White, Nathan S. and Steed, Tyler Christian and Bartsch, Hauke and Holland, Dominic and Farid, Nikdokht and McDonald, Carrie R. and Carter, Bob S. and Dale, Anders Martin and Chen, Clark C.},
        doi = {10.1371/journal.pone.0152472},
        issn = {1932-6203},
        journal = {PLOS ONE},
        number = 3,
        pages = {e0152472},
        title = {Characterization and Correction of Geometric Distortions in 814 Diffusion Weighted Images},
        url = {http://journals.plos.org/plosone/article?id=10.1371/journal.pone.0152472},
        volume = 11,
        year = 2016
    }

    @article{flirt,
        title = {A global optimisation method for robust affine registration of brain images},
        volume = {5},
        issn = {1361-8415},
        url = {http://www.sciencedirect.com/science/article/pii/S1361841501000366},
        doi = {10.1016/S1361-8415(01)00036-6},
        number = {2},
        urldate = {2018-07-27},
        journal = {Medical Image Analysis},
        author = {Jenkinson, Mark and Smith, Stephen},
        year = {2001},
        keywords = {Affine transformation, flirt, fsl, Global optimisation, Multi-resolution search, Multimodal registration, Robustness},
        pages = {143--156}
    }

    @article{mcflirt,
        author = {Jenkinson, Mark and Bannister, Peter and Brady, Michael and Smith, Stephen},
        doi = {10.1006/nimg.2002.1132},
        issn = {1053-8119},
        journal = {NeuroImage},
        number = 2,
        pages = {825-841},
        title = {Improved Optimization for the Robust and Accurate Linear Registration and Motion Correction of Brain Images},
        url = {http://www.sciencedirect.com/science/article/pii/S1053811902911328},
        volume = 17,
        year = 2002
    }

    @article{bbr,
        author = {Greve, Douglas N and Fischl, Bruce},
        doi = {10.1016/j.neuroimage.2009.06.060},
        issn = {1095-9572},
        journal = {NeuroImage},
        number = 1,
        pages = {63-72},
        title = {Accurate and robust brain image alignment using boundary-based registration},
        volume = 48,
        year = 2009
    }

    @article{aroma,
        author = {Pruim, Raimon H. R. and Mennes, Maarten and van Rooij, Daan and Llera, Alberto and Buitelaar, Jan K. and Beckmann, Christian F.},
        doi = {10.1016/j.neuroimage.2015.02.064},
        issn = {1053-8119},
        journal = {NeuroImage},
        number = {Supplement C},
        pages = {267-277},
        shorttitle = {ICA-AROMA},
        title = {ICA-{AROMA}: A robust {ICA}-based strategy for removing motion artifacts from fMRI data},
        url = {http://www.sciencedirect.com/science/article/pii/S1053811915001822},
        volume = 112,
        year = 2015
    }

    @article{power_fd_dvars,
        author = {Power, Jonathan D. and Mitra, Anish and Laumann, Timothy O. and Snyder, Abraham Z. and Schlaggar, Bradley L. and Petersen, Steven E.},
        doi = {10.1016/j.neuroimage.2013.08.048},
        issn = {1053-8119},
        journal = {NeuroImage},
        number = {Supplement C},
        pages = {320-341},
        title = {Methods to detect, characterize, and remove motion artifact in resting state fMRI},
        url = {http://www.sciencedirect.com/science/article/pii/S1053811913009117},
        volume = 84,
        year = 2014
    }

    @article{confounds_satterthwaite_2013,
        author = {Satterthwaite, Theodore D. and Elliott, Mark A. and Gerraty, Raphael T. and Ruparel, Kosha and Loughead, James and Calkins, Monica E. and Eickhoff, Simon B. and Hakonarson, Hakon and Gur, Ruben C. and Gur, Raquel E. and Wolf, Daniel H.},
        doi = {10.1016/j.neuroimage.2012.08.052},
        issn = {10538119},
        journal = {NeuroImage},
        number = 1,
        pages = {240--256},
        title = {{An improved framework for confound regression and filtering for control of motion artifact in the preprocessing of resting-state functional connectivity data}},
        url = {http://linkinghub.elsevier.com/retrieve/pii/S1053811912008609},
        volume = 64,
        year = 2013
    }

    @article{nilearn,
        author = {Abraham, Alexandre and Pedregosa, Fabian and Eickenberg, Michael and Gervais, Philippe and Mueller, Andreas and Kossaifi, Jean and Gramfort, Alexandre and Thirion, Bertrand and Varoquaux, Gael},
        doi = {10.3389/fninf.2014.00014},
        issn = {1662-5196},
        journal = {Frontiers in Neuroinformatics},
        language = {English},
        title = {Machine learning for neuroimaging with scikit-learn},
        url = {https://www.frontiersin.org/articles/10.3389/fninf.2014.00014/full},
        volume = 8,
        year = 2014
    }

    @article{lanczos,
        author = {Lanczos, C.},
        doi = {10.1137/0701007},
        issn = {0887-459X},
        journal = {Journal of the Society for Industrial and Applied Mathematics Series B Numerical Analysis},
        number = 1,
        pages = {76-85},
        title = {Evaluation of Noisy Data},
        url = {http://epubs.siam.org/doi/10.1137/0701007},
        volume = 1,
        year = 1964
    }

    @article{compcor,
        author = {Behzadi, Yashar and Restom, Khaled and Liau, Joy and Liu, Thomas T.},
        doi = {10.1016/j.neuroimage.2007.04.042},
        issn = {1053-8119},
        journal = {NeuroImage},
        number = 1,
        pages = {90-101},
        title = {A component based noise correction method ({CompCor}) for {BOLD} and perfusion based fMRI},
        url = {http://www.sciencedirect.com/science/article/pii/S1053811907003837},
        volume = 37,
        year = 2007
    }

    @article{hcppipelines,
        author = {Glasser, Matthew F. and Sotiropoulos, Stamatios N. and Wilson, J. Anthony and Coalson, Timothy S. and Fischl, Bruce and Andersson, Jesper L. and Xu, Junqian and Jbabdi, Saad and Webster, Matthew and Polimeni, Jonathan R. and Van Essen, David C. and Jenkinson, Mark},
        doi = {10.1016/j.neuroimage.2013.04.127},
        issn = {1053-8119},
        journal = {NeuroImage},
        pages = {105-124},
        series = {Mapping the Connectome},
        title = {The minimal preprocessing pipelines for the Human Connectome Project},
        url = {http://www.sciencedirect.com/science/article/pii/S1053811913005053},
        volume = 80,
        year = 2013
    }

    @article{fs_template,
        author = {Reuter, Martin and Rosas, Herminia Diana and Fischl, Bruce},
        doi = {10.1016/j.neuroimage.2010.07.020},
        journal = {NeuroImage},
        number = 4,
        pages = {1181-1196},
        title = {Highly accurate inverse consistent registration: A robust approach},
        volume = 53,
        year = 2010
    }

    @article{afni,
        author = {Cox, Robert W. and Hyde, James S.},
        doi = {10.1002/(SICI)1099-1492(199706/08)10:4/5<171::AID-NBM453>3.0.CO;2-L},
        journal = {NMR in Biomedicine},
        number = {4-5},
        pages = {171-178},
        title = {Software tools for analysis and visualization of fMRI data},
        volume = 10,
        year = 1997
    }

    @article{posse_t2s,
        author = {Posse, Stefan and Wiese, Stefan and Gembris, Daniel and Mathiak, Klaus and Kessler, Christoph and Grosse-Ruyken, Maria-Liisa and Elghahwagi, Barbara and Richards, Todd and Dager, Stephen R. and Kiselev, Valerij G.},
        doi = {10.1002/(SICI)1522-2594(199907)42:1<87::AID-MRM13>3.0.CO;2-O},
        journal = {Magnetic Resonance in Medicine},
        number = 1,
        pages = {87-97},
        title = {Enhancement of {BOLD}-contrast sensitivity by single-shot multi-echo functional {MR} imaging},
        volume = 42,
        year = 1999
    }

# Errors

No errors to report!